@@ -4,14 +4,16 @@ use strict;
 BEGIN {
 	require 5.004;
 	require Exporter;
-	$YAML::Tiny::VERSION   = '1.31';
+	$YAML::Tiny::VERSION   = '1.35';
 	$YAML::Tiny::errstr    = '';
 	@YAML::Tiny::ISA       = qw{ Exporter  };
+	@YAML::Tiny::EXPORT = qw{
+		Load Dump
+	};
 	@YAML::Tiny::EXPORT_OK = qw{
-		Load     Dump
 		LoadFile DumpFile
 		freeze   thaw
-		};
+	};
 }
 
 my $ESCAPE_CHAR = '[\\x00-\\x08\\x0b-\\x0d\\x0e-\\x1f\"\n]';
@@ -332,7 +334,7 @@ sub write_string {
 
 		# A scalar document
 		} elsif ( ! ref $cursor ) {
-			$lines[-1] .= ' ' . $self->_write_scalar( $cursor );
+			$lines[-1] .= ' ' . $self->_write_scalar( $cursor, $indent );
 
 		# A list at the root
 		} elsif ( ref $cursor eq 'ARRAY' ) {
@@ -385,7 +387,7 @@ sub _write_array {
 		my $line = ('  ' x $indent) . '-';
 		my $type = ref $el;
 		if ( ! $type ) {
-			$line .= ' ' . $self->_write_scalar( $el );
+			$line .= ' ' . $self->_write_scalar( $el, $indent + 1 );
 			push @lines, $line;
 
 		} elsif ( $type eq 'ARRAY' ) {
@@ -425,7 +427,7 @@ sub _write_hash {
 		my $line = ('  ' x $indent) . "$name:";
 		my $type = ref $el;
 		if ( ! $type ) {
-			$line .= ' ' . $self->_write_scalar( $el );
+			$line .= ' ' . $self->_write_scalar( $el, $indent + 1 );
 			push @lines, $line;
 
 		} elsif ( $type eq 'ARRAY' ) {
